@@ -10,18 +10,21 @@
 
 int main(){
 
+    //open the SLOW5 file
     slow5_file_t *sp = slow5_open(FILE_PATH,"r");
     if(sp==NULL){
        fprintf(stderr,"Error in opening file\n");
        exit(EXIT_FAILURE);
     }
-    slow5_rec_t *rec = NULL;
-    int ret=0;
 
+    slow5_rec_t *rec = NULL; //slow5 record to be read
+    int ret=0; //for return value
+
+    //iterate through the file until end
     while((ret = slow5_get_next(&rec,sp)) >= 0){
         printf("%s\t",rec->read_id);
         uint64_t len_raw_signal = rec->len_raw_signal;
-        for(uint64_t i=0;i<len_raw_signal;i++){
+        for(uint64_t i=0;i<len_raw_signal;i++){ //iterate through the raw signal and print in picoamperes
             double pA = TO_PICOAMPS(rec->raw_signal[i],rec->digitisation,rec->offset,rec->range);
             printf("%f ",pA);
         }
@@ -33,8 +36,11 @@ int main(){
         exit(EXIT_FAILURE);
     }
 
+    //free the SLOW5 record
     slow5_rec_free(rec);
 
+    //close the SLOW5 file
     slow5_close(sp);
 
+    return 0;
 }
